# cortado: high performance 100% Python package for machine learning

## Installation

*cortado* can be installed from pip:

```
pip install cortado
```

## Main features:
* native support for both numeric and categorical data (*covariates* and *factors*)
* innovative feature engineering: virtual data columns and easy conversions between numeric and categorical data
* out of core data processing when dataframes are bigger than RAM
* implementation of XGBoost logistic in 500 lines of Python code, 3x faster than original C++ implementation (using Numba jit under the hood)
* easy to extend, written in functional style for easy composition
* works well with pandas dataframes
* more to come soon!

## Demo notebooks on Kaggle:
* [Quick start](https://www.kaggle.com/neostat/cortado-quick-start)
* [Cortado vs XGBoost](https://www.kaggle.com/neostat/cortado-vs-xgboost)
* [Factors and covariates](https://www.kaggle.com/neostat/cortado-factors-and-covariates)
* [Out of core processing](https://www.kaggle.com/neostat/cortado-out-of-core)

## How to contribute

All contributions and bug reports are welcome.